@@ -6,7 +6,7 @@ This file is part of minos framework.
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
 
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 from .broker import (
     Command,
@@ -25,6 +25,9 @@ from .configuration import (
     MinosConfig,
     MinosConfigAbstract,
 )
+from .database import (
+    PostgreSqlMinosDatabase,
+)
 from .exceptions import (
     EmptyMinosModelSequenceException,
     MinosAttributeValidationException,
